@@ -1,6 +1,5 @@
 import redis
 import cloudpickle
-import pickle
 
 class GearsRemoteLocalGroupByStep():
     def __init__(self, extractor, reducer):
@@ -222,7 +221,7 @@ class GearsRemoteBuilder():
         self.pipe = GearsPipe(reader, defaultArg)
         self.requirements = requirements
         if addClientToRequirements:
-            self.requirements += ['gearsclient==1.0.1']
+            self.requirements += ['git+https://github.com/RedisGears/redisgears-py.git']
         if len(self.requirements) > 0:
             self.requirements = ['REQUIREMENTS'] + self.requirements
 
@@ -332,7 +331,6 @@ class atomic:
     def __init__(self):
         from redisgears import atomicCtx as redisAtomic
         self.atomic = redisAtomic()
-        pass
 
     def __enter__(self):
         self.atomic.__enter__()
